@@ -8,19 +8,19 @@ options(width=60)
 
 
 ###################################################
-### code chunk number 2: polysattutorial.Rnw:218-219
+### code chunk number 2: polysattutorial.Rnw:219-220
 ###################################################
 getwd()
 
 
 ###################################################
-### code chunk number 3: polysattutorial.Rnw:226-227
+### code chunk number 3: polysattutorial.Rnw:227-228
 ###################################################
 simgen <- read.GeneMapper("GeneMapperExample.txt")
 
 
 ###################################################
-### code chunk number 4: polysattutorial.Rnw:235-240
+### code chunk number 4: polysattutorial.Rnw:236-241
 ###################################################
 summary(simgen)
 Samples(simgen)
@@ -30,7 +30,7 @@ find.missing.gen(simgen)
 
 
 ###################################################
-### code chunk number 5: polysattutorial.Rnw:248-252
+### code chunk number 5: polysattutorial.Rnw:249-253
 ###################################################
 Description(simgen) <- "Dataset for the tutorial"
 PopNames(simgen) <- c("PopA", "PopB", "PopC")
@@ -39,51 +39,51 @@ Usatnts(simgen) <- c(2, 3, 2)
 
 
 ###################################################
-### code chunk number 6: polysattutorial.Rnw:259-261
+### code chunk number 6: polysattutorial.Rnw:260-262
 ###################################################
 rep(1:3, each = 100)
 PopInfo(simgen)
 
 
 ###################################################
-### code chunk number 7: polysattutorial.Rnw:266-267
+### code chunk number 7: polysattutorial.Rnw:267-268
 ###################################################
 Samples(simgen, populations = "PopA")
 
 
 ###################################################
-### code chunk number 8: polysattutorial.Rnw:278-279
+### code chunk number 8: polysattutorial.Rnw:279-280
 ###################################################
 Usatnts(simgen)
 
 
 ###################################################
-### code chunk number 9: polysattutorial.Rnw:314-316
+### code chunk number 9: polysattutorial.Rnw:315-317
 ###################################################
 simgen <- reformatPloidies(simgen, output="sample")
 Ploidies(simgen) <- read.table("vignettebuild/simgenPloidies2.txt")[[1]]
 
 
 ###################################################
-### code chunk number 10: polysattutorial.Rnw:321-322
+### code chunk number 10: polysattutorial.Rnw:322-323
 ###################################################
 summary(simgen)
 
 
 ###################################################
-### code chunk number 11: polysattutorial.Rnw:333-334
+### code chunk number 11: polysattutorial.Rnw:334-335
 ###################################################
 save(simgen, file="simgen.RData")
 
 
 ###################################################
-### code chunk number 12: polysattutorial.Rnw:353-354
+### code chunk number 12: polysattutorial.Rnw:354-355
 ###################################################
 load("vignettebuild/testmat.RData")
 
 
 ###################################################
-### code chunk number 13: polysattutorial.Rnw:357-361
+### code chunk number 13: polysattutorial.Rnw:358-362
 ###################################################
 pca <- cmdscale(testmat)
 mycol <- c("red", "green", "blue")
@@ -92,13 +92,13 @@ plot(pca[,1], pca[,2], col=mycol[PopInfo(simgen)],
 
 
 ###################################################
-### code chunk number 14: polysattutorial.Rnw:372-373
+### code chunk number 14: polysattutorial.Rnw:373-374
 ###################################################
 load("vignettebuild/testmat2.RData")
 
 
 ###################################################
-### code chunk number 15: polysattutorial.Rnw:376-379
+### code chunk number 15: polysattutorial.Rnw:377-380
 ###################################################
 pca2 <- cmdscale(testmat2)
 plot(pca2[,1], pca2[,2], col=rep(c("red", "green", "blue"), each=100),
@@ -106,7 +106,7 @@ plot(pca2[,1], pca2[,2], col=rep(c("red", "green", "blue"), each=100),
 
 
 ###################################################
-### code chunk number 16: polysattutorial.Rnw:400-403
+### code chunk number 16: polysattutorial.Rnw:404-407
 ###################################################
 simgen2 <- deleteSamples(simgen, c("B59", "C30"))
 simgen2 <- deleteLoci(simgen2, "loc2")
@@ -114,7 +114,7 @@ summary(simgen2)
 
 
 ###################################################
-### code chunk number 17: polysattutorial.Rnw:411-415
+### code chunk number 17: polysattutorial.Rnw:415-419
 ###################################################
 samToUse <- Samples(simgen2, populations=c("PopA", "PopB"), ploidies=4)
 exclude <- c("A50", "A78", "B25", "B60", "B81")
@@ -123,13 +123,13 @@ samToUse
 
 
 ###################################################
-### code chunk number 18: polysattutorial.Rnw:425-426
+### code chunk number 18: polysattutorial.Rnw:429-430
 ###################################################
 summary(simgen2[samToUse, "loc1"])
 
 
 ###################################################
-### code chunk number 19: polysattutorial.Rnw:433-438
+### code chunk number 19: polysattutorial.Rnw:437-442
 ###################################################
 testmat3 <- meandistance.matrix(simgen2, samples = samToUse,
                                 distmetric = Lynch.distance,
@@ -139,13 +139,13 @@ plot(pca3[,1], pca3[,2], col=c("red", "blue")[PopInfo(simgen2)[samToUse]])
 
 
 ###################################################
-### code chunk number 20: polysattutorial.Rnw:486-487
+### code chunk number 20: polysattutorial.Rnw:490-491
 ###################################################
 simfreq <- read.table("vignettebuild/simfreq.txt")
 
 
 ###################################################
-### code chunk number 21: polysattutorial.Rnw:490-503
+### code chunk number 21: polysattutorial.Rnw:494-507
 ###################################################
 simfreq
 simFst <- calcPopDiff(simfreq, metric = "Fst")
@@ -163,19 +163,49 @@ simD12
 
 
 ###################################################
-### code chunk number 22: polysattutorial.Rnw:519-520
+### code chunk number 22: polysattutorial.Rnw:514-515
+###################################################
+PIC(simfreq)
+
+
+###################################################
+### code chunk number 23: polysattutorial.Rnw:521-522
+###################################################
+calcPopDiff(simfreq, metric = "Gst", global = TRUE)
+
+
+###################################################
+### code chunk number 24: polysattutorial.Rnw:529-542
+###################################################
+gbootstrap <- calcPopDiff(simfreq, metric = "Gst", global = TRUE, 
+                          bootstrap = TRUE)
+quantile(gbootstrap, c(0.025, 0.975))
+gbootstrap_pairwise <- calcPopDiff(simfreq, metric = "Gst", 
+                                   bootstrap = TRUE)
+pairwise_CIs <- lapply(gbootstrap_pairwise, 
+                       function(x) quantile(x, c(0.025,0.975)))
+names(pairwise_CIs) <- paste(rep(PopNames(simgen), 
+                                 each = length(PopNames(simgen))),
+                             rep(PopNames(simgen), 
+                                 times = length(PopNames(simgen))), 
+                             sep = ".")
+pairwise_CIs
+
+
+###################################################
+### code chunk number 25: polysattutorial.Rnw:558-559
 ###################################################
 write.Structure(simgen, ploidy = 4, file="simgenStruct.txt")
 
 
 ###################################################
-### code chunk number 23: polysattutorial.Rnw:570-571
+### code chunk number 26: polysattutorial.Rnw:609-610
 ###################################################
 showClass("genambig")
 
 
 ###################################################
-### code chunk number 24: polysattutorial.Rnw:579-582
+### code chunk number 27: polysattutorial.Rnw:618-621
 ###################################################
 mysamples <- c("indA", "indB", "indC", "indD", "indE", "indF")
 myloci <- c("loc1", "loc2", "loc3")
@@ -183,13 +213,13 @@ mydataset <- new("genambig", samples=mysamples, loci=myloci)
 
 
 ###################################################
-### code chunk number 25: polysattutorial.Rnw:588-589
+### code chunk number 28: polysattutorial.Rnw:627-628
 ###################################################
 mydataset
 
 
 ###################################################
-### code chunk number 26: polysattutorial.Rnw:607-622
+### code chunk number 29: polysattutorial.Rnw:646-661
 ###################################################
 Loci(mydataset)
 Loci(mydataset) <- c("L1", "L2", "L3")
@@ -209,7 +239,7 @@ Ploidies(mydataset)
 
 
 ###################################################
-### code chunk number 27: polysattutorial.Rnw:625-640
+### code chunk number 30: polysattutorial.Rnw:664-679
 ###################################################
 Ploidies(mydataset)["indC1",] <- 6
 Ploidies(mydataset)
@@ -229,14 +259,14 @@ Genotypes(mydataset)
 
 
 ###################################################
-### code chunk number 28: polysattutorial.Rnw:646-648
+### code chunk number 31: polysattutorial.Rnw:685-687
 ###################################################
 mydataset@Genotypes
 mydataset@Genotypes[["indB","L1"]]
 
 
 ###################################################
-### code chunk number 29: polysattutorial.Rnw:661-664
+### code chunk number 32: polysattutorial.Rnw:700-703
 ###################################################
 isMissing(mydataset, "indA", "L2")
 isMissing(mydataset, "indA", "L1")
@@ -244,7 +274,7 @@ isMissing(mydataset)
 
 
 ###################################################
-### code chunk number 30: polysattutorial.Rnw:671-681
+### code chunk number 33: polysattutorial.Rnw:710-720
 ###################################################
 moredata <- new("genambig", samples=c("indG", "indH"), loci=Loci(mydataset))
 Usatnts(moredata) <- Usatnts(mydataset)
@@ -259,7 +289,7 @@ mydataset2
 
 
 ###################################################
-### code chunk number 31: polysattutorial.Rnw:733-746
+### code chunk number 34: polysattutorial.Rnw:772-785
 ###################################################
 ploidyexample <- new("genambig")
 Samples(ploidyexample)
@@ -277,13 +307,13 @@ Ploidies(ploidyexample)
 
 
 ###################################################
-### code chunk number 32: polysattutorial.Rnw:754-755
+### code chunk number 35: polysattutorial.Rnw:793-794
 ###################################################
 Ploidies(ploidyexample)["ind1", "loc1"]
 
 
 ###################################################
-### code chunk number 33: polysattutorial.Rnw:763-766
+### code chunk number 36: polysattutorial.Rnw:802-805
 ###################################################
 Ploidies(ploidyexample, "ind1", "loc1")
 ploidyexample <- reformatPloidies(ploidyexample, output="one")
@@ -291,7 +321,7 @@ Ploidies(ploidyexample, "ind1", "loc1")
 
 
 ###################################################
-### code chunk number 34: polysattutorial.Rnw:795-798
+### code chunk number 37: polysattutorial.Rnw:834-837
 ###################################################
 simgenB <- genambig.to.genbinary(simgen)
 Genotypes(simgenB, samples=paste("A", 1:20, sep=""), loci="loc1")
@@ -299,13 +329,13 @@ PopInfo(simgenB)[Samples(simgenB, ploidies=2)]
 
 
 ###################################################
-### code chunk number 35: polysattutorial.Rnw:804-805
+### code chunk number 38: polysattutorial.Rnw:843-844
 ###################################################
 write.table(Genotypes(simgenB), file="simBinaryData.txt")
 
 
 ###################################################
-### code chunk number 36: polysattutorial.Rnw:858-862
+### code chunk number 39: polysattutorial.Rnw:897-901
 ###################################################
 GDdata <- read.GenoDive("genodiveExample.txt")
 Structdata <- read.Structure("structureExample.txt", ploidy = 8)
@@ -314,7 +344,7 @@ PDdata <- read.POPDIST(c("POPDISTexample1.txt", "POPDISTexample2.txt"))
 
 
 ###################################################
-### code chunk number 37: polysattutorial.Rnw:902-905
+### code chunk number 40: polysattutorial.Rnw:941-944
 ###################################################
 GMdata <- read.GeneMapper(c("GeneMapperCBA15.txt",
                             "GeneMapperCBA23.txt",
@@ -322,7 +352,7 @@ GMdata <- read.GeneMapper(c("GeneMapperCBA15.txt",
 
 
 ###################################################
-### code chunk number 38: polysattutorial.Rnw:914-920
+### code chunk number 41: polysattutorial.Rnw:953-959
 ###################################################
 # view the format
 read.table("STRandExample.txt", sep="\t", header=TRUE)
@@ -333,14 +363,14 @@ PopNames(STRdata)
 
 
 ###################################################
-### code chunk number 39: polysattutorial.Rnw:929-931
+### code chunk number 42: polysattutorial.Rnw:968-970
 ###################################################
 domdata <- read.table("dominantExample.txt", header=TRUE,
                       sep="\t", row.names=1)
 
 
 ###################################################
-### code chunk number 40: polysattutorial.Rnw:939-944
+### code chunk number 43: polysattutorial.Rnw:978-983
 ###################################################
 domdata
 domdata <- as.matrix(domdata)
@@ -350,14 +380,14 @@ Genotypes(PAdata) <- domdata
 
 
 ###################################################
-### code chunk number 41: polysattutorial.Rnw:952-954
+### code chunk number 44: polysattutorial.Rnw:991-993
 ###################################################
 PopInfo(PAdata) <- c(1,1,2)
 PAdata <- genbinary.to.genambig(PAdata)
 
 
 ###################################################
-### code chunk number 42: polysattutorial.Rnw:983-989
+### code chunk number 45: polysattutorial.Rnw:1022-1028
 ###################################################
 myexcol <- array(c(rep(0:1, each=150), seq(0.1, 30, by=0.1)), dim=c(300,2),
                  dimnames = list(Samples(simgen), c("PopFlag", "Something")))
@@ -368,32 +398,32 @@ write.Structure(simgen, ploidy=4, file="simgenStruct2.txt",
 
 
 ###################################################
-### code chunk number 43: polysattutorial.Rnw:997-998
+### code chunk number 46: polysattutorial.Rnw:1036-1037
 ###################################################
 write.GenoDive(simgen, file="simgenGD.txt")
 
 
 ###################################################
-### code chunk number 44: polysattutorial.Rnw:1010-1011
+### code chunk number 47: polysattutorial.Rnw:1049-1050
 ###################################################
 write.SPAGeDi(simgen, file="simgenSpag.txt")
 
 
 ###################################################
-### code chunk number 45: polysattutorial.Rnw:1024-1026
+### code chunk number 48: polysattutorial.Rnw:1063-1065
 ###################################################
 write.POPDIST(simgen, samples = Samples(simgen, ploidies=4),
               file = "simgenPOPDIST.txt")
 
 
 ###################################################
-### code chunk number 46: polysattutorial.Rnw:1036-1037
+### code chunk number 49: polysattutorial.Rnw:1075-1076
 ###################################################
 write.GeneMapper(simgen, file="simgenGM.txt")
 
 
 ###################################################
-### code chunk number 47: polysattutorial.Rnw:1046-1049
+### code chunk number 50: polysattutorial.Rnw:1085-1088
 ###################################################
 simgenPA <- genambig.to.genbinary(simgen)
 write.table(Genotypes(simgenPA), file="simgenPA.txt", quote=FALSE,
@@ -401,20 +431,20 @@ write.table(Genotypes(simgenPA), file="simgenPA.txt", quote=FALSE,
 
 
 ###################################################
-### code chunk number 48: polysattutorial.Rnw:1061-1063
+### code chunk number 51: polysattutorial.Rnw:1100-1102
 ###################################################
 write.table(data.frame(Ploidies(simgen), row.names=Samples(simgen)),
             file="simgenPloidies.txt")
 
 
 ###################################################
-### code chunk number 49: polysattutorial.Rnw:1114-1115
+### code chunk number 52: polysattutorial.Rnw:1153-1154
 ###################################################
 load("vignettebuild/testmat4.RData")
 
 
 ###################################################
-### code chunk number 50: polysattutorial.Rnw:1117-1120
+### code chunk number 53: polysattutorial.Rnw:1156-1159
 ###################################################
 pca4 <- cmdscale(testmat4)
 plot(pca4[,1], pca4[,2], col=c("red", "blue")[PopInfo(simgen)[samToUse]],
@@ -422,25 +452,25 @@ plot(pca4[,1], pca4[,2], col=c("red", "blue")[PopInfo(simgen)[samToUse]],
 
 
 ###################################################
-### code chunk number 51: polysattutorial.Rnw:1128-1129
+### code chunk number 54: polysattutorial.Rnw:1167-1168
 ###################################################
 hist(as.vector(testmat))
 
 
 ###################################################
-### code chunk number 52: polysattutorial.Rnw:1131-1132
+### code chunk number 55: polysattutorial.Rnw:1170-1171
 ###################################################
 hist(as.vector(testmat2))
 
 
 ###################################################
-### code chunk number 53: polysattutorial.Rnw:1134-1135
+### code chunk number 56: polysattutorial.Rnw:1173-1174
 ###################################################
 write.table(testmat2, file="simgenDistMat.txt")
 
 
 ###################################################
-### code chunk number 54: polysattutorial.Rnw:1156-1166
+### code chunk number 57: polysattutorial.Rnw:1195-1205
 ###################################################
 subsamples <- Samples(simgen, populations=1)
 subsamples <- subsamples[!isMissing(simgen, subsamples, "loc1") &
@@ -455,7 +485,7 @@ mdist1.3 <- meandist.from.array(Larray, loci=c("loc1","loc3"))
 
 
 ###################################################
-### code chunk number 55: polysattutorial.Rnw:1189-1192
+### code chunk number 58: polysattutorial.Rnw:1228-1231
 ###################################################
 clones <- assignClones(testmat, samples=paste("A", 1:100, sep=""),
                        threshold=0.2)
@@ -463,7 +493,7 @@ clones
 
 
 ###################################################
-### code chunk number 56: polysattutorial.Rnw:1209-1212
+### code chunk number 59: polysattutorial.Rnw:1248-1251
 ###################################################
 simal <- alleleDiversity(simgen)
 simal$counts
@@ -471,7 +501,7 @@ simal$alleles[["PopA","loc1"]]
 
 
 ###################################################
-### code chunk number 57: polysattutorial.Rnw:1251-1255
+### code chunk number 60: polysattutorial.Rnw:1290-1294
 ###################################################
 simFst
 simfreqSimple <- simpleFreq(simgen, samples = Samples(simgen, ploidies=4))
@@ -480,25 +510,25 @@ simFstSimple
 
 
 ###################################################
-### code chunk number 58: polysattutorial.Rnw:1268-1269
+### code chunk number 61: polysattutorial.Rnw:1307-1308
 ###################################################
 write.freq.SPAGeDi(simfreq, usatnts=Usatnts(simgen), file="SPAGfreq.txt")
 
 
 ###################################################
-### code chunk number 59: polysattutorial.Rnw:1279-1280
+### code chunk number 62: polysattutorial.Rnw:1318-1319
 ###################################################
 gpsimfreq <- freq.to.genpop(simfreq)
 
 
 ###################################################
-### code chunk number 60: polysattutorial.Rnw:1310-1311
+### code chunk number 63: polysattutorial.Rnw:1349-1350
 ###################################################
 load("vignettebuild/testmat5.RData")
 
 
 ###################################################
-### code chunk number 61: polysattutorial.Rnw:1313-1317
+### code chunk number 64: polysattutorial.Rnw:1352-1356
 ###################################################
 simdiv <- genotypeDiversity(simgen, d=testmat5, threshold=0.2, index=Shannon)
 simdiv
@@ -507,7 +537,7 @@ simdiv2
 
 
 ###################################################
-### code chunk number 62: polysattutorial.Rnw:1323-1327
+### code chunk number 65: polysattutorial.Rnw:1362-1366
 ###################################################
 simdiv2var <- genotypeDiversity(simgen, d=testmat5, threshold=0.2,
                                 index=Simpson.var)
@@ -516,14 +546,14 @@ simdiv2 + 2*simdiv2var^0.5
 
 
 ###################################################
-### code chunk number 63: polysattutorial.Rnw:1375-1377
+### code chunk number 66: polysattutorial.Rnw:1414-1416
 ###################################################
 ATdata <- read.ATetra("ATetraExample.txt")
 Tetdata <- read.Tetrasat("tetrasatExample.txt")
 
 
 ###################################################
-### code chunk number 64: polysattutorial.Rnw:1388-1391
+### code chunk number 67: polysattutorial.Rnw:1427-1430
 ###################################################
 write.ATetra(simgen, samples=Samples(simgen, ploidies=4), file="simgenAT.txt")
 write.Tetrasat(simgen, samples=Samples(simgen, ploidies=4),
@@ -531,7 +561,7 @@ write.Tetrasat(simgen, samples=Samples(simgen, ploidies=4),
 
 
 ###################################################
-### code chunk number 65: polysattutorial.Rnw:1466-1470
+### code chunk number 68: polysattutorial.Rnw:1505-1509
 ###################################################
 Present(simgenB) <- "P"
 Absent(simgenB) <- 2
@@ -540,7 +570,7 @@ Genotypes(simgenB)[1:10, 1:6]
 
 
 ###################################################
-### code chunk number 66: polysattutorial.Rnw:1476-1479
+### code chunk number 69: polysattutorial.Rnw:1515-1518
 ###################################################
 genmat <- Genotypes(simgenB)
 dimnames(genmat)[[2]] <- paste("M", 1:dim(genmat)[2], sep="")
